==> qiho-center-biz-1.2.4-sources.jar: com/qiho/center/biz/event/LogisticsInfoUpdateEvent.java <==
package com.qiho.center.biz.event;

import com.qiho.center.api.enums.LogisticsOrderStatusEnum;
import com.qiho.center.common.annotations.AsyncEvent;

/**
 * Created by liuyao on 2017/6/13. 事件中的字段必须完整
 */
@AsyncEvent
public class LogisticsInfoUpdateEvent {

    private String orderId;

    /** 物流订单ID */
    private String logisticsId;

    /** 物流公司代码 */
    private String logisticsCode;

    /** 物流公司名称 */
    private String logisticsName;

    /** 物流单号 */
    private String postId;

    /** 物流状态，具体由物流公司定义 */
    private String logisticsStatus;

    /** 物流订单状态，{@link LogisticsOrderStatusEnum} */
    private String orderStatus;

    /** 收货电话 */
    private String mobile;

    /**
     * orderId.
     *
     * @return the orderId
     */
    public String getOrderId() {
        return orderId;
    }

    /**
     * orderId.
     *
     * @param orderId the orderId to set
     */
    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    /**
     * logisticsId.
     *
     * @return the logisticsId
     */
    public String getLogisticsId() {
        return logisticsId;
    }

    /**
     * logisticsId.
     *
     * @param logisticsId the logisticsId to set
     */
    public void setLogisticsId(String logisticsId) {
        this.logisticsId = logisticsId;
    }

    /**
     * logisticsCode.
     *
     * @return the logisticsCode
     */
    public String getLogisticsCode() {
        return logisticsCode;
    }

    /**
     * logisticsCode.
     *
     * @param logisticsCode the logisticsCode to set
     */
    public void setLogisticsCode(String logisticsCode) {
        this.logisticsCode = logisticsCode;
    }

    /**
     * logisticsName.
     *
     * @return the logisticsName
     */
    public String getLogisticsName() {
        return logisticsName;
    }

    /**
     * logisticsName.
     *
     * @param logisticsName the logisticsName to set
     */
    public void setLogisticsName(String logisticsName) {
        this.logisticsName = logisticsName;
    }

    /**
     * postId.
     *
     * @return the postId
     */
    public String getPostId() {
        return postId;
    }

    /**
     * postId.
     *
     * @param postId the postId to set
     */
    public void setPostId(String postId) {
        this.postId = postId;
    }

    /**
     * logisticsStatus.
     *
     * @return the logisticsStatus
     */
    public String getLogisticsStatus() {
        return logisticsStatus;
    }

    /**
     * logisticsStatus.
     *
     * @param logisticsStatus the logisticsStatus to set
     */
    public void setLogisticsStatus(String logisticsStatus) {
        this.logisticsStatus = logisticsStatus;
    }

    /**
     * orderStatus.
     *
     * @return the orderStatus
     */
    public String getOrderStatus() {
        return orderStatus;
    }

    /**
     * orderStatus.
     *
     * @param orderStatus the orderStatus to set
     */
    public void setOrderStatus(String orderStatus) {
        this.orderStatus = orderStatus;
    }

    /**
     * mobile.
     *
     * @return the mobile
     */
    public String getMobile() {
        return mobile;
    }

    /**
     * mobile.
     *
     * @param mobile the mobile to set
     */
    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

}

==> qiho-center-biz-2.2.1-sources.jar: com/qiho/center/biz/event/LogisticsInfoUpdateEvent.java <==
package com.qiho.center.biz.event;

import com.qiho.center.api.enums.LogisticsOrderStatusEnum;
import com.qiho.center.common.annotations.AsyncEvent;

/**
 * Created by liuyao on 2017/6/13. 事件中的字段必须完整
 */
@AsyncEvent
public class LogisticsInfoUpdateEvent {

    private String orderId;

    /** 物流订单ID */
    private String logisticsId;

    /** 物流公司代码 */
    private String logisticsCode;

    /** 物流公司名称 */
    private String logisticsName;

    /** 物流单号 */
    private String postId;

    /** 物流状态，具体由物流公司定义 */
    private String logisticsStatus;

    /** 物流订单状态，{@link LogisticsOrderStatusEnum} */
    private String orderStatus;

    /** 收货电话 */
    private String mobile;

    /** 用户姓名 */
    private String consumerName;

    /**
     * orderId.
     *
     * @return the orderId
     */
    public String getOrderId() {
        return orderId;
    }

    /**
     * orderId.
     *
     * @param orderId the orderId to set
     */
    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    /**
     * logisticsId.
     *
     * @return the logisticsId
     */
    public String getLogisticsId() {
        return logisticsId;
    }

    /**
     * logisticsId.
     *
     * @param logisticsId the logisticsId to set
     */
    public void setLogisticsId(String logisticsId) {
        this.logisticsId = logisticsId;
    }

    /**
     * logisticsCode.
     *
     * @return the logisticsCode
     */
    public String getLogisticsCode() {
        return logisticsCode;
    }

    /**
     * logisticsCode.
     *
     * @param logisticsCode the logisticsCode to set
     */
    public void setLogisticsCode(String logisticsCode) {
        this.logisticsCode = logisticsCode;
    }

    /**
     * logisticsName.
     *
     * @return the logisticsName
     */
    public String getLogisticsName() {
        return logisticsName;
    }

    /**
     * logisticsName.
     *
     * @param logisticsName the logisticsName to set
     */
    public void setLogisticsName(String logisticsName) {
        this.logisticsName = logisticsName;
    }

    /**
     * postId.
     *
     * @return the postId
     */
    public String getPostId() {
        return postId;
    }

    /**
     * postId.
     *
     * @param postId the postId to set
     */
    public void setPostId(String postId) {
        this.postId = postId;
    }

    /**
     * logisticsStatus.
     *
     * @return the logisticsStatus
     */
    public String getLogisticsStatus() {
        return logisticsStatus;
    }

    /**
     * logisticsStatus.
     *
     * @param logisticsStatus the logisticsStatus to set
     */
    public void setLogisticsStatus(String logisticsStatus) {
        this.logisticsStatus = logisticsStatus;
    }

    /**
     * orderStatus.
     *
     * @return the orderStatus
     */
    public String getOrderStatus() {
        return orderStatus;
    }

    /**
     * orderStatus.
     *
     * @param orderStatus the orderStatus to set
     */
    public void setOrderStatus(String orderStatus) {
        this.orderStatus = orderStatus;
    }

    /**
     * mobile.
     *
     * @return the mobile
     */
    public String getMobile() {
        return mobile;
    }

    /**
     * mobile.
     *
     * @param mobile the mobile to set
     */
    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getConsumerName() {
        return consumerName;
    }

    public void setConsumerName(String consumerName) {
        this.consumerName = consumerName;
    }
}
